@@ -1,10 +1,7 @@
 #!/usr/bin/perl
 use strict;
 use warnings;
-use lib './lib';
-use Class::STL::Containers;
-use Class::STL::Algorithms;
-use Class::STL::Utilities;
+use stl;
 
 print ">>>$0>>>>:\n";
 my $v = list(data_type => 'MyElem');
@@ -14,15 +11,15 @@ $v->push_back($v->factory(data => 'third'));
 $v->push_back($v->factory(data => 'fourth'));
 $v->push_back($v->factory(data => 'fifth'));
 for_each($v->begin(), $v->end(), ptr_fun('::myprint'));
-print 'Class::STL::Algorithms::foreach($v->begin(), $v->end(), ptr_fun(\'uc\'));', "\n";
+print 'for_each($v->begin(), $v->end(), ptr_fun(\'uc\'));', "\n";
 for_each($v->begin(), $v->end(), ptr_fun('uc'));
 for_each($v->begin(), $v->end(), ptr_fun('::myprint'));
-print 'Class::STL::Algorithms::foreach($v->begin(), $v->end(), "something");', "\n";
+print 'for_each($v->begin(), $v->end(), "something");', "\n";
 for_each($v->begin(), $v->end(), mem_fun('something'));
 
-print "Static Foreach with mem_fun():\n";
+print "for_each with mem_fun():\n";
 for_each($v->begin(), $v->end(), mem_fun('something'));
-print "Static Foreach with unary-function-object:\n";
+print "for_each with unary-function-object:\n";
 for_each($v->begin(), $v->end(), ptr_fun('::myprint'));
 
 sub myprint { print "Data:", @_, "\n"; }
